export declare class BuildTask {
    result: InternalBuildResult;
    cache: BuilderAssetCache;
}

export class BuilderAssetCache {
    // 场景资源的 assets 信息缓存
    public readonly scenes: Array<IBuildSceneItem>;

    // 脚本资源的 assets 信息缓存
    public readonly scriptUuids: Array<string>;

    // 除场景、脚本资源外的资源 assets uuid 缓存
    public readonly assetUuids: Array<string>;

    init: () => Promise<void>;
    addAsset: (asset: IAssetInfo) => void;
    addInstance: (instance: any) => void;
    clearAsset: (uuid: string) => void;
    getMeta: (uuid: string) => Promise<any>;
    addMeta: (uuid: string, meta: any) => void;
    getAssetInfo: (uuid: string) => IAssetInfo;
    getDependUuids: (uuid: string) => Promise<readonly string[]>;
    getDependUuidsDeep: (uuid: string) => Promise<readonly string[]>;
    /**
     * 获取序列化文件
     */
    getLibraryJSON: (uuid: string) => Promise<any>;
    getSerializedJSON: (uuid: string, options: IInternalBuildOptions) => Promise<any>;
    forEach: (type: string, handle: Function) => Promise<void>;
    getInstance: (uuid: string) => Promise<any>;
    __addStaticsInfo: (info: Record<string, any>) => void;
}

export class InternalBuildResult {
    settings: ISettings;
    readonly bundles: IBundle[];
    readonly bundleMap: Record<string, IBundle>;
    // 构建实际使用到的插件脚本 uuid 列表
    plugins: UUID[];
    // 脚本资源包分组（子包/分包）
    scriptPackages: string[];
    // MD5 后缀 map
    pluginVers: Record<UUID, string>;
    // 纹理压缩任务
    public imageCompressTaskMap: Record<UUID, ImageCompressTask>;

    // 纹理压缩结果存储
    public compressImageResult: ICompressImageResult;
    importMap: ImportMapWithImports;
    // 传入构建的 options
    rawOptions: IBuildTaskOption;
    // 输出路径集合
    paths: IBuildPaths;
    // 允许自定义编译选项
    compileOptions?: any;
    addBundle: (bundle: IBundle) => void;
    addPlugin: (plugin: IAssetInfo) => void;
    addImageTask: (uuid: string, taskInfo: { src: string, dest: string, presetId: string, bundleName: string, hasAlpha: boolean, mtime?: string }) => void;
    removeImageTask: (uuid: string) => void;
    getMipmapFiles: (file: string, destDir?: string) => Promise<string[]>;
}