"use strict";
const fs = require("fs-extra");
const path = require("path");
const name = "vite-vue-extensions-template";
const title = "vite-vue-extensions-template";
const package_version = 2;
const version = "1.0.0";
const author = "zeta";
const main = "./dist/main.js";
const scripts = {
  build: "vue-tsc --noEmit && vite build",
  watch: "vite build --watch"
};
const dependencies = {
  "fs-extra": "^10.0.0",
  typescript: "^5.3.3",
  vue: "^3.4.21"
};
const devDependencies = {
  "@types/express": "^4.17.21",
  "@types/fs-extra": "^5.0.4",
  "@types/node": "^18.0.0",
  "@vitejs/plugin-vue": "^4.0.0",
  vite: "^5.2.0",
  "vue-tsc": "^2.0.6"
};
const type = "module";
const panels = {
  "input-dialog": {
    title: "Input Dialog",
    type: "simple",
    main: "dist/panels/input-dialog",
    size: {
      width: 300,
      height: 200
    },
    flags: {
      resizable: false
    }
  }
};
const contributions = {
  builder: "./dist/builder.js",
  server: "./dist/server.js",
  scene: {
    script: "./dist/scene.js"
  },
  menu: [
    {
      path: "tools",
      label: "test",
      message: "test"
    }
  ],
  messages: {
    test: {
      methods: [
        "test"
      ]
    },
    "get-config": {
      methods: [
        "getConfig"
      ]
    }
  }
};
const packageJson = {
  name,
  title,
  package_version,
  version,
  author,
  main,
  scripts,
  dependencies,
  devDependencies,
  type,
  panels,
  contributions
};
function getPackageName() {
  return packageJson.name;
}
function getPackagePath() {
  return Editor.Package.getPath(getPackageName());
}
function getPackagePanelName(panelName) {
  return `${getPackageName()}.${panelName}`;
}
function openPackagePanel(panelName, ...args) {
  Editor.Panel.open(getPackagePanelName(panelName), args);
}
function closePackagePanel(panelName) {
  Editor.Panel.close(getPackagePanelName(panelName));
}
function loadCss() {
  const packagePath = getPackagePath();
  return fs.readFileSync(path.join(packagePath, "./dist/assets/style.css"), "utf-8") + fs.readFileSync(path.join(packagePath, "./public/style.css"), "utf-8");
}
exports.closePackagePanel = closePackagePanel;
exports.loadCss = loadCss;
exports.openPackagePanel = openPackagePanel;
