import vue from "@vitejs/plugin-vue";
import { builtinModules } from "module";
import { defineConfig } from "vite";
import packageJson from "./package.json";

// 入口都往这里加，如 scenes、build-hooks 等，文件放在 src 下
const entries = [
	"main",
]

// 面板都往这里加，文件放在 src/panels 下
const panels = [
	"input-dialog"
];

const input: Record<string, string> = {}

// https://vitejs.dev/config/
export default defineConfig({
	base: "./",
	mode: "development",
	plugins: [vue({
		template: {
			compilerOptions: {
				isCustomElement: tag => tag.startsWith("ui-")
			}
		}
	})],
	build: {
		assetsDir: "assets",
		minify: false,
		cssMinify: false,
		cssCodeSplit: false,
		outDir: "dist",
		copyPublicDir: false,
		rollupOptions: {
			preserveEntrySignatures: "allow-extension",
			input: {
				"main": "src/main.ts",

				"panels/input-dialog": "src/panels/input-dialog/index.ts",
			},
			output: {
				format: "cjs",
				entryFileNames: "[name].js",
				assetFileNames: "assets/[name].[ext]",
			},
			external: [
				"cc",
				"electron",
				"@electron/remote",
				...Object.keys(packageJson.dependencies),
				...builtinModules
			],
		},

	},
});
